@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -33,6 +35,13 @@ class DetectFraudKOLRequest(AbstractModel):
         if params.get("BspData") is not None:
             self.BspData = InputKolBspData()
             self.BspData._deserialize(params.get("BspData"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DetectFraudKOLResponse(AbstractModel):
@@ -76,6 +85,13 @@ class EnhanceTaDegreeRequest(AbstractModel):
         if params.get("BspData") is not None:
             self.BspData = InputTaBspData()
             self.BspData._deserialize(params.get("BspData"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class EnhanceTaDegreeResponse(AbstractModel):
@@ -122,6 +138,13 @@ class InputKolBspData(AbstractModel):
                 obj = InputKolDataList()
                 obj._deserialize(item)
                 self.DataList.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class InputKolDataList(AbstractModel):
@@ -155,6 +178,19 @@ class InputKolDataList(AbstractModel):
         self.Name = params.get("Name")
         self.Phone = params.get("Phone")
         self.AgentInfo = params.get("AgentInfo")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class InputRecognizeEffectiveFlow(AbstractModel):
+    """接口入参
+
+    """
 
 
 class InputRecognizeTargetAudience(AbstractModel):
@@ -320,6 +356,13 @@ class InputRecognizeTargetAudience(AbstractModel):
         self.AppName = params.get("AppName")
         self.AppVer = params.get("AppVer")
         self.ReqType = params.get("ReqType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class InputSendTrafficSecuritySmsMsg(AbstractModel):
@@ -341,6 +384,13 @@ class InputSendTrafficSecuritySmsMsg(AbstractModel):
     def _deserialize(self, params):
         self.TaskId = params.get("TaskId")
         self.Mobiles = params.get("Mobiles")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class InputTaBspData(AbstractModel):
@@ -454,6 +504,13 @@ class InputTaBspData(AbstractModel):
         self.Latitude = params.get("Latitude")
         self.Longitude = params.get("Longitude")
         self.Context = params.get("Context")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class OutputKolData(AbstractModel):
@@ -487,6 +544,13 @@ class OutputKolData(AbstractModel):
                 obj = OutputKolValue()
                 obj._deserialize(item)
                 self.Value.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class OutputKolValue(AbstractModel):
@@ -520,6 +584,80 @@ class OutputKolValue(AbstractModel):
         self.IsCheck = params.get("IsCheck")
         self.FraudPScore = params.get("FraudPScore")
         self.EvilPScore = params.get("EvilPScore")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class OutputRecognizeEffectiveFlow(AbstractModel):
+    """业务出参
+
+    """
+
+    def __init__(self):
+        """
+        :param Code: 返回码。0表示成功，非0标识失败错误码
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Code: int
+        :param Message: UTF-8编码，出错消息。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Message: str
+        :param Value: 业务入参
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Value: :class:`tencentcloud.taf.v20200210.models.OutputRecognizeEffectiveFlowValue`
+        """
+        self.Code = None
+        self.Message = None
+        self.Value = None
+
+
+    def _deserialize(self, params):
+        self.Code = params.get("Code")
+        self.Message = params.get("Message")
+        if params.get("Value") is not None:
+            self.Value = OutputRecognizeEffectiveFlowValue()
+            self.Value._deserialize(params.get("Value"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class OutputRecognizeEffectiveFlowValue(AbstractModel):
+    """业务出参
+
+    """
+
+    def __init__(self):
+        """
+        :param Lable: 返回标签
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Lable: str
+        :param Score: 返回分值
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Score: float
+        """
+        self.Lable = None
+        self.Score = None
+
+
+    def _deserialize(self, params):
+        self.Lable = params.get("Lable")
+        self.Score = params.get("Score")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class OutputRecognizeTargetAudience(AbstractModel):
@@ -552,6 +690,13 @@ class OutputRecognizeTargetAudience(AbstractModel):
                 obj = OutputRecognizeTargetAudienceValue()
                 obj._deserialize(item)
                 self.Value.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class OutputRecognizeTargetAudienceValue(AbstractModel):
@@ -580,6 +725,13 @@ class OutputRecognizeTargetAudienceValue(AbstractModel):
         self.ModelId = params.get("ModelId")
         self.IsFound = params.get("IsFound")
         self.Score = params.get("Score")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class OutputSendTrafficSecuritySmsMsg(AbstractModel):
@@ -607,6 +759,13 @@ class OutputSendTrafficSecuritySmsMsg(AbstractModel):
         self.Code = params.get("Code")
         self.Message = params.get("Message")
         self.Value = params.get("Value")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class OutputTaData(AbstractModel):
@@ -636,6 +795,13 @@ class OutputTaData(AbstractModel):
         if params.get("Value") is not None:
             self.Value = OutputTaValue()
             self.Value._deserialize(params.get("Value"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class OutputTaValue(AbstractModel):
@@ -659,6 +825,13 @@ class OutputTaValue(AbstractModel):
     def _deserialize(self, params):
         self.IsCheck = params.get("IsCheck")
         self.IsMatch = params.get("IsMatch")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RecognizeCustomizedAudienceRequest(AbstractModel):
@@ -678,6 +851,13 @@ class RecognizeCustomizedAudienceRequest(AbstractModel):
         if params.get("BspData") is not None:
             self.BspData = InputRecognizeTargetAudience()
             self.BspData._deserialize(params.get("BspData"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RecognizeCustomizedAudienceResponse(AbstractModel):
@@ -704,6 +884,55 @@ class RecognizeCustomizedAudienceResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class RecognizeEffectiveFlowRequest(AbstractModel):
+    """RecognizeEffectiveFlow请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param BusinessSecurityData: 业务入参
+        :type BusinessSecurityData: :class:`tencentcloud.taf.v20200210.models.InputRecognizeEffectiveFlow`
+        """
+        self.BusinessSecurityData = None
+
+
+    def _deserialize(self, params):
+        if params.get("BusinessSecurityData") is not None:
+            self.BusinessSecurityData = InputRecognizeEffectiveFlow()
+            self.BusinessSecurityData._deserialize(params.get("BusinessSecurityData"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class RecognizeEffectiveFlowResponse(AbstractModel):
+    """RecognizeEffectiveFlow返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Data: 业务出参
+        :type Data: :class:`tencentcloud.taf.v20200210.models.OutputRecognizeEffectiveFlow`
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Data = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Data") is not None:
+            self.Data = OutputRecognizeEffectiveFlow()
+            self.Data._deserialize(params.get("Data"))
+        self.RequestId = params.get("RequestId")
+
+
 class RecognizePreciseTargetAudienceRequest(AbstractModel):
     """RecognizePreciseTargetAudience请求参数结构体
 
@@ -721,6 +950,13 @@ class RecognizePreciseTargetAudienceRequest(AbstractModel):
         if params.get("BspData") is not None:
             self.BspData = InputRecognizeTargetAudience()
             self.BspData._deserialize(params.get("BspData"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RecognizePreciseTargetAudienceResponse(AbstractModel):
@@ -764,6 +1000,13 @@ class RecognizeTargetAudienceRequest(AbstractModel):
         if params.get("BspData") is not None:
             self.BspData = InputRecognizeTargetAudience()
             self.BspData._deserialize(params.get("BspData"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class RecognizeTargetAudienceResponse(AbstractModel):
@@ -807,6 +1050,13 @@ class SendTrafficSecuritySmsMessageRequest(AbstractModel):
         if params.get("BspData") is not None:
             self.BspData = InputSendTrafficSecuritySmsMsg()
             self.BspData._deserialize(params.get("BspData"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SendTrafficSecuritySmsMessageResponse(AbstractModel):
